@@ -1,6 +1,5 @@
 # Author: Robert J. Hijmans
 # Date :  June 2008
-# Version 0.8 (taken from Raster package)
 # Licence GPL v3
 
 # distance based on law of cosines
@@ -8,10 +7,13 @@
 
 distCosine <- function(p1, p2, r=6378137) {
 	toRad <- pi / 180 
+	
 	p1 <- .pointsToMatrix(p1) * toRad
 	p2 <- .pointsToMatrix(p2) * toRad
 	
 	p = cbind(p1[,1], p1[,2], p2[,1], p2[,2], as.vector(r))
+	
+	z <- isTRUE(p1[,1] == p2[,1] &  p1[,2] == p2[,2]) # distance is zero
 
 	lon1 <- p[,1]
 	lat1 <- p[,2]
@@ -20,12 +22,11 @@ distCosine <- function(p1, p2, r=6378137) {
 	r <- p[,5]
 
 	cosd <- sin(lat1) * sin(lat2) + cos(lat1) * cos(lat2) * cos(lon1-lon2)
-	dist <- r * acos(cosd) 
+	dist <- matrix(nrow=nrow(p), ncol=1)
+	dist[z] <- 0
+	dist[!z] <- r[!z] * acos(cosd[!z]) 
 
-	if (is.vector(dist)) { dist <- matrix(dist) }
 	colnames(dist) <- 'distance'
-	
 	return(dist)
 }
 
-
