@@ -3,7 +3,6 @@
 # version 1
 # license GPL3
 
-
 .normalizeLonDeg <- function(x) {
 	x <- (x + 180) %% 360 - 180
 }
@@ -13,15 +12,23 @@
 }
 
 
-.isPolygon <- function(x) {
+.isPolygon <- function(x, fix=FALSE) {
+	x <- na.omit(x)
 	if (nrow(x) < 4) {
 		stop('this is not a polygon (insufficent number of vertices)')
 	}
-	if (! isTRUE(all.equal(x[1,], x[nrow(x),]))) {
-		stop('this is not a valid (closed) polygon (first vertex must be equal to the last vertex)')
+	if (length(unique(x[,1]))==1) {
+		stop('All longitudes are the same (not a polygon)')
+	}
+	if (length(unique(x[,2]))==1) {
+		stop('All latitudes are the same (not a polygon)')
 	}
 	if (! all(!(is.na(x))) ) {
 		stop('polygon has NA values)')
 	}
-	return(TRUE)
+	if (! isTRUE(all.equal(x[1,], x[nrow(x),]))) {
+		stop('this is not a valid (closed) polygon. The first vertex is not equal to the last vertex')	
+	}
+	return(x)
 }
+
